.. include:: ../README.rst


Authors
-------

.. toctree::
   :maxdepth: 2

   authors


Contributing
------------

.. toctree::
   :maxdepth: 2

   contributing


History
-------

.. toctree::
   :maxdepth: 2

   history


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

